@@ -356,10 +356,10 @@ class ImageInfo ( HasPrivateTraits ):
 
     def _get_image_info_code ( self ):
         data = dict((name, repr(value))
-                    for name, value in self.trait_get(
+                    for name, value in iter(self.trait_get(
                         'name', 'image_name', 'description', 'category',
                         'keywords', 'alignment'
-                    ).items())
+                    ).items()))
         data.update(self.trait_get('width', 'height'))
         sides = ['left', 'right', 'top', 'bottom']
         data.update(('b'+name, getattr(self.border, name)) for name in sides)
@@ -691,10 +691,10 @@ class ImageVolume ( HasPrivateTraits ):
 
     def _get_image_volume_code ( self ):
         data = dict((name, repr(value))
-                    for name, value in self.trait_get(
+                    for name, value in iter(self.trait_get(
                         'description', 'category', 'keywords', 'aliases',
                         'time_stamp'
-                    ).items())
+                    ).items()))
         data['info'] = ',\n'.join(info.image_volume_info_code
                                   for info in self.info)
         return (ImageVolumeTemplate % data)
