@@ -1,41 +1,56 @@
 
 
-from traits.testing.unittest_tools import unittest, UnittestTools
+from traits.testing.unittest_tools import unittest
 
 from ..gui import GUI
 from ..image_resource import ImageResource
 from ..splash_screen import SplashScreen
+from ..toolkit import toolkit_object
+
+GuiTestAssistant = toolkit_object('util.gui_test_assistant:GuiTestAssistant')
+no_gui_test_assistant = (GuiTestAssistant.__name__ == 'Unimplemented')
 
 
-class TestWindow(unittest.TestCase, UnittestTools):
+@unittest.skipIf(no_gui_test_assistant, 'No GuiTestAssistant')
+class TestWindow(unittest.TestCase, GuiTestAssistant):
 
     def setUp(self):
-        self.gui = GUI()
+        GuiTestAssistant.setUp(self)
         self.window = SplashScreen()
 
+    def tearDown(self):
+        if self.window.control is not None:
+            with self.delete_widget(self.window.control):
+                self.window.destroy()
+
+        del self.window
+        GuiTestAssistant.tearDown(self)
+
     def test_destroy(self):
         # test that destroy works even when no control
         self.window.destroy()
+        self.event_loop()
 
     def test_open_close(self):
         # test that opening and closing works as expected
         with self.assertTraitChanges(self.window, 'opening', count=1):
             with self.assertTraitChanges(self.window, 'opened', count=1):
                 self.window.open()
-        self.gui.process_events()
+        self.event_loop()
         with self.assertTraitChanges(self.window, 'closing', count=1):
             with self.assertTraitChanges(self.window, 'closed', count=1):
                 self.window.close()
-        self.gui.process_events()
+        self.event_loop()
 
     def test_show(self):
         # test that show works as expected
         self.window._create()
         self.window.show(True)
-        self.gui.process_events()
+        self.event_loop()
         self.window.show(False)
-        self.gui.process_events()
+        self.event_loop()
         self.window.destroy()
+        self.event_loop()
 
     def test_image(self):
         # test that images work
@@ -43,11 +58,11 @@ class TestWindow(unittest.TestCase, UnittestTools):
         with self.assertTraitChanges(self.window, 'opening', count=1):
             with self.assertTraitChanges(self.window, 'opened', count=1):
                 self.window.open()
-        self.gui.process_events()
+        self.event_loop()
         with self.assertTraitChanges(self.window, 'closing', count=1):
             with self.assertTraitChanges(self.window, 'closed', count=1):
                 self.window.close()
-        self.gui.process_events()
+        self.event_loop()
 
     def test_text(self):
         # test that images work
@@ -55,11 +70,11 @@ class TestWindow(unittest.TestCase, UnittestTools):
         with self.assertTraitChanges(self.window, 'opening', count=1):
             with self.assertTraitChanges(self.window, 'opened', count=1):
                 self.window.open()
-        self.gui.process_events()
+        self.event_loop()
         with self.assertTraitChanges(self.window, 'closing', count=1):
             with self.assertTraitChanges(self.window, 'closed', count=1):
                 self.window.close()
-        self.gui.process_events()
+        self.event_loop()
 
     def test_text_changed(self):
         # test that images work
@@ -68,10 +83,10 @@ class TestWindow(unittest.TestCase, UnittestTools):
         with self.assertTraitChanges(self.window, 'opening', count=1):
             with self.assertTraitChanges(self.window, 'opened', count=1):
                 self.window.open()
-        self.gui.process_events()
+        self.event_loop()
         self.window.text = "Splash screen"
-        self.gui.process_events()
+        self.event_loop()
         with self.assertTraitChanges(self.window, 'closing', count=1):
             with self.assertTraitChanges(self.window, 'closed', count=1):
                 self.window.close()
-        self.gui.process_events()
+        self.event_loop()
