@@ -9,22 +9,33 @@
 
 """ Tests for the tabular editor tester. """
 
+
 import unittest
 import io
+import platform
 
 from pyface.qt import QtGui
-from pyface.api import MessageDialog, OK, CANCEL
+from pyface.api import Dialog, MessageDialog, OK, CANCEL
+from pyface.toolkit import toolkit_object
 from traits.api import HasStrictTraits
-from traitsui.api import CancelButton, OKButton, View
 
 from pyface.ui.qt4.util.testing import silence_output
 from pyface.ui.qt4.util.gui_test_assistant import GuiTestAssistant
 from pyface.ui.qt4.util.modal_dialog_tester import ModalDialogTester
+from pyface.util.testing import skip_if_no_traitsui
+
+
+is_qt = toolkit_object.toolkit == 'qt4'
+if is_qt:
+    from pyface.qt import qt_api
+is_pyqt5 = (is_qt and qt_api == 'pyqt5')
 
 
 class MyClass(HasStrictTraits):
 
     def default_traits_view(self):
+        from traitsui.api import CancelButton, OKButton, View
+
         view = View(
             buttons=[OKButton, CancelButton],
             resizable=False,
@@ -42,6 +53,7 @@ class MyClass(HasStrictTraits):
         return True
 
 
+@unittest.skipIf(is_pyqt5, "ModalDialogTester not working on pyqt5. Issue #302")
 class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
     """ Tests for the modal dialog tester. """
 
@@ -63,6 +75,7 @@ class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
         self.assertEqual(tester.result, CANCEL)
         self.assertTrue(tester.dialog_was_opened)
 
+    @skip_if_no_traitsui
     def test_on_traitsui_dialog(self):
         my_class = MyClass()
         tester = ModalDialogTester(my_class.run)
@@ -79,6 +92,19 @@ class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
         self.assertEqual(tester.result, 'rejected')
         self.assertTrue(tester.dialog_was_opened)
 
+    @skip_if_no_traitsui
+    def test_dialog_was_not_opened_on_traitsui_dialog(self):
+        my_class = MyClass()
+        tester = ModalDialogTester(my_class.do_not_show_dialog)
+
+        # it runs okay
+        tester.open_and_run(when_opened=lambda x: x.close(accept=True))
+        self.assertTrue(tester.value_assigned())
+        self.assertEqual(tester.result, True)
+
+        # but no dialog is opened
+        self.assertFalse(tester.dialog_was_opened)
+
     def test_capture_errors_on_failure(self):
         dialog = MessageDialog()
         tester = ModalDialogTester(dialog.open)
@@ -90,6 +116,7 @@ class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
                     self.fail()
             finally:
                 tester.close()
+                self.gui.process_events()
 
         with self.assertRaises(AssertionError):
             alt_stderr = io.StringIO
@@ -108,6 +135,7 @@ class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
                     1 / 0
             finally:
                 tester.close()
+                self.gui.process_events()
 
         with self.assertRaises(ZeroDivisionError):
             alt_stderr = io.StringIO
@@ -115,15 +143,16 @@ class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
                 tester.open_and_run(when_opened=raise_error)
             self.assertIn('ZeroDivisionError', alt_stderr)
 
+    @unittest.skip("has_widget code not working as designed. Issue #282.")
     def test_has_widget(self):
-        my_class = MyClass()
-        tester = ModalDialogTester(my_class.run)
+        dialog = Dialog()
+        tester = ModalDialogTester(dialog.open)
 
         def check_and_close(tester):
             try:
                 with tester.capture_error():
                     self.assertTrue(
-                        tester.has_widget('OK', QtGui.QPushButton)
+                        tester.has_widget('OK', QtGui.QAbstractButton)
                     )
                     self.assertFalse(
                         tester.has_widget(text='I am a virtual button')
@@ -133,15 +162,16 @@ class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
 
         tester.open_and_run(when_opened=check_and_close)
 
+    @unittest.skip("has_widget code not working as designed. Issue #282.")
     def test_find_widget(self):
-        my_class = MyClass()
-        tester = ModalDialogTester(my_class.run)
+        dialog = Dialog()
+        tester = ModalDialogTester(dialog.open)
 
         def check_and_close(tester):
             try:
                 with tester.capture_error():
                     widget = tester.find_qt_widget(
-                        type_=QtGui.QPushButton,
+                        type_=QtGui.QAbstractButton,
                         test=lambda x: x.text() == 'OK'
                     )
                     self.assertIsInstance(widget, QtGui.QPushButton)
@@ -150,18 +180,6 @@ class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
 
         tester.open_and_run(when_opened=check_and_close)
 
-    def test_dialog_was_not_opened_on_traitsui_dialog(self):
-        my_class = MyClass()
-        tester = ModalDialogTester(my_class.do_not_show_dialog)
-
-        # it runs okay
-        tester.open_and_run(when_opened=lambda x: x.close(accept=True))
-        self.assertTrue(tester.value_assigned())
-        self.assertEqual(tester.result, True)
-
-        # but no dialog is opened
-        self.assertFalse(tester.dialog_was_opened)
-
 
 if __name__ == '__main__':
     unittest.main()
