@@ -711,12 +711,12 @@ class SplitTabWidget(QtGui.QSplitter):
                 h = rect.height()
                 if top_bottom:
                     tab_widths = sum(tab_bar.tabRect(i).width()
-                        for i in range(tab_bar.count()))
+                        for i in list(range(tab_bar.count())))
                     w -= tab_widths
                     gx += tab_widths
                 else:
                     tab_heights = sum(tab_bar.tabRect(i).height()
-                        for i in range(tab_bar.count()))
+                        for i in list(range(tab_bar.count())))
                     h -= tab_heights
                     gy -= tab_heights
                 return (tw, self._HS_AFTER_LAST_TAB, (gx, gy, w, h))
